Finite resource limits applied to one complete procedure call tree.
Summary
Functions
Builds finite limits from a keyword list or map.
Types
@type t() :: %Tursox.Procedures.Limits{ max_argument_bytes: term(), max_database_bytes: term(), max_heap_size: term(), max_instructions: term(), max_lua_call_depth: term(), max_procedure_calls: term(), max_procedure_depth: term(), max_result_bytes: term(), max_rows: term(), max_source_bytes: term(), max_statements: term(), max_string_bytes: term(), timeout: term() }
Functions
@spec new(keyword() | map()) :: {:ok, t()} | {:error, Tursox.Procedures.Error.t()}
Builds finite limits from a keyword list or map.